@@ -89,17 +89,9 @@ if (typeof window.onload != 'function') {
 
 
  function resetDokuWikiLockTimer() {
-  if(locktimer.reset == locktimer.old_reset) {
-        unsetDokuWikiLockTimer();
-        locktimer.refresh();
-        if(locktimer.our_refreshID) window.clearTimeout(locktimer.our_refreshID);
-        locktimer.our_refreshID =  window.setTimeout("locktimer.refresh()", (3*60000));
-        return; 
-  }
-  if(locktimer.our_refreshID) window.clearTimeout(locktimer.our_refreshID);
-  locktimer.reset = locktimer.old_reset;
-  locktimer.warning = locktimer.old_warning;
-  locktimer.reset();
+
+  unsetDokuWikiLockTimer();
+
  }
 
 </script>
